@@ -7,6 +7,8 @@
 ######################################################################
 
 use strict;
+use Fcntl;
+use Symbol;
 
 for my $io (
     ['Esjis.pm' => 'Esjis.pm'],
@@ -55,6 +57,35 @@ This software is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
+=head1 ShiftJIS Encoding
+
+ShiftJIS encoding is the most common encoding method used on Japanese
+computers, developed by Microsoft Corporation.
+
+ShiftJIS is sometimes referred to as MS Kanji (Microsoft Kanji) or SJIS
+(an abbreviation for ShiftJIS).
+
+Historically, ShiftJIS was so named because of the way the code positions
+for two-octet characters shifted around the code positions for half-width
+katakana -- Japanese computer users originally used only half-width katakana,
+so ShiftJIS was developed in order to maintain backword compatibility.
+
+A two-octet-per-character mode in ShiftJIS is initiated with a octet having
+a hexadecimal value ranging between 0x81-0x9F or 0xE0-0xEF. This octet is
+subsequently treated as the first octet of an expected two-octet sequence.
+The following (second) octet must have a hexadecimal value ranging between
+0x40-0x7E or 0x80-0xFC. Note that the first octet's range falls entirely in
+the extended ASCII character set -- in the eight-bit character set with the
+high-order bit on. Note that ShiftJIS also encodes half-width katakana and
+ASCII/JIS-Roman.
+
+Some definitions (in particular, corporate definitions) of ShiftJIS also
+contain encoding blocks for user-defined characters or even an encoded position
+for a half-width katakana space character. Such encoding blocks and encoded
+positions are not useful if true information interchange is desired, because
+they are encoded in such a way that they do not convert to encoded positions
+in other Japanese encoding methods (that is, JIS and EUC).
+
 =head1 ShiftJIS IN WIKIPEDIA
 
 Shift JIS (2008.02.15 15:02:00 JST). In Wikipedia: The Free Encyclopedia.
@@ -135,8 +166,8 @@ The distinction is done only by first octet.
       * Final octet of string like first octet of double octet code
 
  So this "ShiftJIS" can handle any code of ShiftJIS based code without
-Informix Ascii 'INFORMIX V6 ALS' is triple octet code.
-(I'm sorry, Informix Ascii users.)
+Hewlett-Packard HP-15 and Informix Ascii 'INFORMIX V6 ALS' is triple octet
+code. (I'm sorry, these users.)
 
 See also code table:
 
@@ -283,6 +314,10 @@ L<http://home.m05.itscom.net/numa/cde/sjis-euc/sjis.html>
  Oracle Oracle7 (Release 7.1.3) 0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x00-0xFF)
  Sybase SQL Server, Open Server 0x00-0x7F, 0xA1-0xDF, (0x81-0x9F, 0xE0-0xFC)(0x40-0x7E, 0x80-0xFC)
 
+Understanding Japanese Information Processing(ISBN 10: 1-56592-043-0 | ISBN 13: 9781565920439)
+
+ Hewlett-Packard HP-15          0x00-0x7F, 0xA1-0xDF, (0x80-0xA0, 0xE0-0xFE)(0x21-0x7E, 0x80-0xFF)
+
 =item * ALGORITHM #2
 
 Against algorithm.1, when the range of the character by tr/// is specified, only the
