@@ -7,7 +7,8 @@ my @c = (
 );
 
 my $script = "q\\q.pl";
-open(SCRIPT,">$script") || die "Can't open file: $script\n";
+open(SCRIPT,">$script")      || die "Can't open file: $script\n";
+open(WANT,  ">$script.want") || die "Can't open file: $script.want\n";
 
 #----------------------------------------------------------------------------
 # ' '
@@ -16,15 +17,18 @@ open(SCRIPT,">$script") || die "Can't open file: $script\n";
 for my $c (@c) {
     if ($c =~ /^['\\]$/) {
         print SCRIPT "print '\\", $c, "', \"\\n\";\n";
+        print WANT $c, "\n";
     }
     else {
         print SCRIPT "print '", $c, "', \"\\n\";\n";
+        print WANT $c, "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "print '", chr($c1), chr($c2), "', \"\\n\";\n";
+        print WANT chr($c1), chr($c2), "\n";
     }
 }
 
@@ -34,11 +38,13 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 
 for my $c (@c, '\\c[') {
     print SCRIPT "print <<'HEREDOC';\n", $c, "\nHEREDOC\n";
+    print WANT $c, "\n";
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "print <<'HEREDOC';\n", chr($c1), chr($c2), "\nHEREDOC\n";
+        print WANT chr($c1), chr($c2), "\n";
     }
 }
 
@@ -48,15 +54,18 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 
 for my $c (@c, '\\c[') {
     print SCRIPT "print <<\\HEREDOC;\n", $c, "\nHEREDOC\n";
+    print WANT $c, "\n";
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "print <<\\HEREDOC;\n", chr($c1), chr($c2), "\nHEREDOC\n";
+        print WANT chr($c1), chr($c2), "\n";
     }
 }
 
 close(SCRIPT);
+close(WANT);
 
 #----------------------------------------------------------------------------
 # q * *
@@ -70,7 +79,8 @@ for my $delim (0x20..0x7E, 0xA1..0xDF) {
     }
 
     my $script = sprintf("q\\q-%02X.pl", $delim);
-    open(SCRIPT,">$script") || die "Can't open file: $script\n";
+    open(SCRIPT,">$script")      || die "Can't open file: $script\n";
+    open(WANT,  ">$script.want") || die "Can't open file: $script.want\n";
 
     my $end_delimiter = {
                         '(' => ')',
@@ -87,19 +97,23 @@ for my $delim (0x20..0x7E, 0xA1..0xDF) {
 
         if ($c =~ /^(\\|\Q$delimiter\E|\Q$end_delimiter\E)$/) {
             print SCRIPT 'print q', $delimiter, '\\', $c, $end_delimiter, ", \"\\n\";\n";
+            print WANT $c, "\n";
         }
         else {
             print SCRIPT 'print q', $delimiter, $c, $end_delimiter, ", \"\\n\";\n";
+            print WANT $c, "\n";
         }
     }
 
     for my $c1 (0x81..0x9F, 0xE0..0xFC) {
         for my $c2 (0x40..0x7E, 0x80..0xFC) {
             print SCRIPT 'print q', $delimiter, chr($c1), chr($c2), $end_delimiter, ", \"\\n\";\n";
+            print WANT chr($c1), chr($c2), "\n";
         }
     }
 
     close(SCRIPT);
+    close(WANT);
 }
 
 #----------------------------------------------------------------------------
